Skip to contents

Fetches contacts and joins custom fields and tags into a single analysis-ready tibble.

Usage

ac_contacts_full(...)

Arguments

...

Arguments passed to ac_contacts() (e.g., email, search, updated_after)

Value

A tibble of contacts with custom field columns and a tags column

Examples

if (FALSE) { # \dontrun{
contacts <- ac_contacts_full()
} # }