Skip to contents

Fetches contacts and all tags, then looks up each contact's tags and appends them as a comma-separated tags column.

Usage

ac_join_contact_tags(...)

Arguments

...

Arguments passed to ac_contacts()

Value

A tibble of contacts with a tags column appended

Examples

if (FALSE) { # \dontrun{
contacts <- ac_join_contact_tags()
} # }