Fetches contacts and joins custom fields and tags into a single analysis-ready tibble.
Arguments
- ...
Arguments passed to
ac_contacts()(e.g.,email,search,updated_after)
Fetches contacts and joins custom fields and tags into a single analysis-ready tibble.
Arguments passed to ac_contacts() (e.g., email, search,
updated_after)