Fetches deals and joins custom fields, stage names, pipeline names, and owner names into a single analysis-ready tibble.
Arguments
- ...
Arguments passed to
ac_deals()(e.g.,status,pipeline,owner,updated_after)
Fetches deals and joins custom fields, stage names, pipeline names, and owner names into a single analysis-ready tibble.
Arguments passed to ac_deals() (e.g., status, pipeline,
owner, updated_after)